# Dropdown field

The dropdown field is a standard select field

![Dropdown fields](../screenshots/fields/waf-dropdown-field.png)

## Configuration options

There are a number of fields that can be manipulated to serve a dropdown field

### Label

The 'name' of the field

### Required

Whether or not it is a required field

### Choices

The options to display in the select dropdown

### Empty label

An empty label to display within the dropdown options

### Default value

Set a default value to display in the dropdown

### Help text

Set the help text to sit alongside the field

### Rules and conditions

Set conditional display rules based on other form field values.


